==> visualizer-0.6.3-sources.jar: org/powertac/visualizer/beans/VisualizerBean.java <==
package org.powertac.visualizer.beans;

import org.apache.log4j.Logger;
import org.joda.time.Instant;
import org.powertac.common.Competition;
import org.powertac.common.msg.TimeslotUpdate;
import org.powertac.visualizer.VisualizerApplicationContext;
import org.powertac.visualizer.domain.DayOverview;
import org.powertac.visualizer.interfaces.Recyclable;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.io.Serializable;
import java.util.List;

/**
 * Holds properties of the Visualizer such as number of received messages from
 * the simulator, number of Visualizer runs etc.
 * 
 * @author Jurica Babic
 */
@Service
public class VisualizerBean implements Serializable {

	private static final long serialVersionUID = 1L;
	private Logger log = Logger.getLogger(VisualizerBean.class);

	private int messageCounter;
	private int visualizerRunCount;

	private DayOverview dayOverview;

	private Competition competition;
	private Instant firstTimeslotInstant;
	private TimeslotUpdate timeslotUpdate;
	private String simulationStatus;
	private int currentTimeslotSerialNumber;
	private int relativeTimeslotIndex;
	private int week;
	private int day;
	private int hour;
	private boolean finished;
	private boolean running;
	private int firstTimeslotIndex;
	private long currentMillis;

	@Autowired
	private AppearanceListBean appearanceList;

	public VisualizerBean() {
		init();
	}

	public void incrementMessageCounter() {
		messageCounter++;
	}

	public int getMessageCount() {
		return messageCounter;
	}

	/**
	 * Configures visualizer bean for the new competition instance. Resets its
	 * properties and increments Visualizer counter.
	 */
	public void newRun() {
		init();
		appearanceList.resetAvailableList(); // so broker appearances will be
		// free for the next competition
		// Recycle:
		List<Recyclable> recyclables = VisualizerApplicationContext.listBeansOfType(Recyclable.class);
		for (Recyclable rec : recyclables) {
			log.info("recycling..." + rec.getClass().getName());
			rec.recycle();
		}
	}

	public void init() {
		messageCounter = 0;
		visualizerRunCount++;

		dayOverview = null;

		competition = null;

		firstTimeslotInstant = null;

		timeslotUpdate = null;
		simulationStatus = null;
		currentTimeslotSerialNumber = -1;
		relativeTimeslotIndex = -1;
		week = -1;
		day = -1;
		hour = -1;
		finished = false;
		running = false;
		firstTimeslotIndex = -1;
		currentMillis = 0;

	}

	public int getVisualizerRunCount() {
		return visualizerRunCount;
	}

	public Competition getCompetition() {
		return competition;
	}

	public void setCompetition(Competition competition) {
		this.competition = competition;
	}

	public TimeslotUpdate getTimeslotUpdate() {
		return timeslotUpdate;
		
	}

	public void setTimeslotUpdate(TimeslotUpdate timeslotUpdate) {
		this.timeslotUpdate = timeslotUpdate;
	}

	public int getCurrentFirstEnabledTimeslotSerialNumber() {
		if (timeslotUpdate != null)
			return timeslotUpdate.getFirstEnabled();
		else {
			return -1;
		}
	}

	public String getSimulationStatus() {
		return simulationStatus;
	}

	public void setSimulationStatus(String simulationStatus) {
		this.simulationStatus = simulationStatus;
	}

	public int getCurrentTimeslotSerialNumber() {
		return currentTimeslotSerialNumber;
	}

	public void setCurrentTimeslotSerialNumber(int currentTimeslotSerialNumber) {
		this.currentTimeslotSerialNumber = currentTimeslotSerialNumber;
	}

	/**
	 * 
	 * 
	 * @param relativeTimeslotIndex
	 */
	public void setRelativeTimeslotIndex(int relativeTimeslotIndex) {
		this.relativeTimeslotIndex = relativeTimeslotIndex;

	}

	public int getRelativeTimeslotIndex() {
		return relativeTimeslotIndex;
	}

	public void setFirstTimeslotInstant(Instant firstTimeslot) {
		this.firstTimeslotInstant = firstTimeslot;
	}

	public Instant getFirstTimeslotInstant() {
		return firstTimeslotInstant;
	}

	public DayOverview getDayOverview() {
		return dayOverview;
	}

	public void setDayOverview(DayOverview dayOverview) {
		this.dayOverview = dayOverview;
	}

	public int getWeek() {
		return week;
	}

	public void setWeek(int week) {
		this.week = week;
	}

	public int getDay() {
		return day;
	}

	public void setDay(int day) {
		this.day = day;
	}

	public int getHour() {
		return hour;
	}

	public void setHour(int hour) {
		this.hour = hour;
	}

	public boolean isFinished() {
		return finished;
	}

	public void setFinished(boolean finished) {
		this.finished = finished;
	}

	public boolean isRunning() {
		return running;
	}

	public void setRunning(boolean running) {
		this.running = running;
	}

	public int getFirstTimeslotIndex() {
		return firstTimeslotIndex;
	}

	public void setFirstTimeslotIndex(int firstTimeslotIndex) {
		this.firstTimeslotIndex = firstTimeslotIndex;
	}
	
	public long getCurrentMillis() {
		return currentMillis;
	}
	public void setCurrentMillis(long currentMillis) {
		this.currentMillis = currentMillis;
	}

}

==> visualizer-1.0.0-sources.jar: org/powertac/visualizer/beans/VisualizerBean.java <==
package org.powertac.visualizer.beans;

import java.io.Serializable;
import java.util.List;

import javax.faces.bean.ManagedBean;

import org.apache.log4j.Logger;
import org.powertac.common.Competition;
import org.powertac.common.msg.TimeslotComplete;
import org.powertac.common.msg.TimeslotUpdate;
import org.powertac.visualizer.VisualizerApplicationContext;
import org.powertac.visualizer.interfaces.Recyclable;
import org.powertac.visualizer.push.NominationCategoryPusher;
import org.powertac.visualizer.push.NominationPusher;
import org.powertac.visualizer.push.WeatherPusher;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * Holds properties of the Visualizer such as number of received messages from
 * the simulator, number of Visualizer runs etc.
 * 
 * @author Jurica Babic
 */
@ManagedBean
@Service
public class VisualizerBean implements Serializable {

	private static final long serialVersionUID = 1L;
	private Logger log = Logger.getLogger(VisualizerBean.class);

	private int messageCounter;
	private int visualizerRunCount;
	private NominationPusher nominationPusher;
	private WeatherPusher weatherPusher;
	private Competition competition;
	private TimeslotUpdate oldTimeslotUpdate;
	private TimeslotUpdate timeslotUpdate;
	private String simulationStatus;
	private int currentTimeslotSerialNumber;
	private boolean finished;
	private boolean running;
	private long currentMillis;
	private TimeslotComplete timeslotComplete;

	@Autowired
	private AppearanceListBean appearanceList;

	private Boolean tournamentMode = false;

	public VisualizerBean() {
		init();
	}

	public void incrementMessageCounter() {
		messageCounter++;
	}

	public int getMessageCount() {
		return messageCounter;
	}

	/**
	 * Configures visualizer bean for the new competition instance. Resets its
	 * properties and increments Visualizer counter.
	 */
	public void newRun() {
		init();
		appearanceList.resetAvailableList(); // so broker appearances will be
		// free for the next competition
		// Recycle:
		List<Recyclable> recyclables = VisualizerApplicationContext
				.listBeansOfType(Recyclable.class);
		for (Recyclable rec : recyclables) {
			log.info("recycling..." + rec.getClass().getName());
			rec.recycle();
		}
	}

	public void init() {
		messageCounter = 0;
		visualizerRunCount++;
		competition = null;
		oldTimeslotUpdate = null;
		timeslotUpdate = null;
		simulationStatus = null;
		currentTimeslotSerialNumber = -1;
		finished = false;
		running = false;

		currentMillis = 0;
		NominationCategoryPusher dummyNc = new NominationCategoryPusher("", 0);
		nominationPusher = new NominationPusher(dummyNc, dummyNc, dummyNc);
		weatherPusher = new WeatherPusher(0, 0, 0, 0, 0);

	}

	public NominationPusher getNominationPusher() {
		return nominationPusher;
	}

	public void setNominationPusher(NominationPusher nominationPusher) {
		this.nominationPusher = nominationPusher;
	}

	public int getVisualizerRunCount() {
		return visualizerRunCount;
	}

	public Competition getCompetition() {
		return competition;
	}

	public void setCompetition(Competition competition) {
		this.competition = competition;
	}

	public TimeslotUpdate getTimeslotUpdate() {
		return timeslotUpdate;

	}

	public void setTimeslotUpdate(TimeslotUpdate timeslotUpdate) {
		this.timeslotUpdate = timeslotUpdate;
	}

	public String getSimulationStatus() {
		return simulationStatus;
	}

	public void setSimulationStatus(String simulationStatus) {
		this.simulationStatus = simulationStatus;
	}

	public int getCurrentTimeslotSerialNumber() {
		return currentTimeslotSerialNumber;
	}

	public void setCurrentTimeslotSerialNumber(int currentTimeslotSerialNumber) {
		this.currentTimeslotSerialNumber = currentTimeslotSerialNumber;
	}

	public boolean isFinished() {
		return finished;
	}

	public void setFinished(boolean finished) {
		this.finished = finished;
	}

	public boolean isRunning() {
		return running;
	}

	public void setRunning(boolean running) {
		this.running = running;
	}

	public long getCurrentMillis() {
		return currentMillis;
	}
	public WeatherPusher getWeatherPusher() {
		return weatherPusher;
	}
	public void setWeatherPusher(WeatherPusher weatherPusher) {
		this.weatherPusher = weatherPusher;
	}

	public void setCurrentMillis(long currentMillis) {
		this.currentMillis = currentMillis;
	}

	public TimeslotUpdate getOldTimeslotUpdate() {
		return oldTimeslotUpdate;
	}

	public void setOldTimeslotUpdate(TimeslotUpdate oldTimeslotUpdate) {
		this.oldTimeslotUpdate = oldTimeslotUpdate;
	}

	public Boolean getTournamentMode() {
		return tournamentMode;
	}

	public void setTournamentMode(Boolean tournamentMode) {
		this.tournamentMode = tournamentMode;
	}

	public TimeslotComplete getTimeslotComplete() {
		return timeslotComplete;
	}

	public void setTimeslotComplete(TimeslotComplete timeslotComplete) {
		this.timeslotComplete = timeslotComplete;
	}
}
